##' Summarize_areas
##'
##' Bring all function calculations together
##' @title summarize_areas_medium
##' @param population The number of people living in a village; default 3800
##' @param kcal_requirement The kcal a human requires per day; default NULL
##' @param household_people The number of people per household; default 5
##' @param forest_type The type of the forest; choose between "oak_mixed_forest" and "olive_mixed_forest"; default "oak_mixed_forest"
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param ... Further arguments passed to other functions
##' @return A tibble
##'
##' @importFrom magrittr "%>%"
##' @importFrom magrittr "%<>%"
##' @export
summarize_areas_medium <- function(
  population = 3800,
  kcal_requirement = NULL,
  household_people = 5.00,
  food_df,
  forest_type = "oak_mixed_forest",
  wood = setup_wood_consumption(population = population, forest_type, ...),
  ...){

  households <- population / household_people

  if (is.null(kcal_requirement)) {
    kcal_req_human_year <- setup_population_simple(
      population = population)$KcalHumanYear
  } else {
    kcal_req_human_year <- setup_population_simple(
      population = population,
      mode = "manual",
      kcal_requirement = kcal_requirement)$KcalHumanYear
  }

  crops <- setup_diet_crops_medium(
    population = population,
    kcal_req_human_year = kcal_req_human_year,
    food_df = food_df)

  arbori <- setup_diet_arbori_gather_medium(
    population = population,
    kcal_req_human_year = kcal_req_human_year,
    food_df = food_df)

  pasture <- setup_diet_pasture_medium(
    population = population,
    food_df = food_df,
    kcal_req_human_year = kcal_req_human_year)

  game <- setup_diet_game_medium(
    population = population,
    food_df = food_df,
    kcal_req_human_year = kcal_req_human_year)

  total_ha <- dplyr::data_frame(
    Category = c("Settlement",
                 "Crops",
                 "Arboriculture/Gathered",
                 "Pasture",
                 "Wood"),
    Area_ha = c(area_village(population = population),
                crops$AreaCrops,
                arbori$AreaArboriGather,
                pasture$AreaPasture,
                wood$area_wood_production_ha
                ),
    Area_prop = Area_ha/sum(Area_ha))

  output_list <- list("Area Requirements" = total_ha,
                      "Crops" = crops$diet,
                      "Arboriculture/Gathered" = arbori$diet,
                      "Domestic Animals" = pasture$diet,
                      "Game" = game$diet)

 return(output_list)
}

