##' Summarize_areas
##'
##' Bring all function calculations together
##' @title summarize_areas_simple
##' @param population The number of people living in a village; default 3800
##' @param kcal_requirement The kcal a human requires per day; default NULL
##' @param household_people The number of people per household; default 5
##' @param consumed_plants The kind of consumed plants
##' @param proportion The percentage amount of each consumed_plants; default NULL
##' @param forest_type The type of the forest; choose between "oak_mixed_forest" and "olive_mixed_forest"; default "oak_mixed_forest"
##' @param wood The required area of woodland to produce ceramics, iron etc.
##' @param pasture The required area for pasture
##' @return A tibble
##'
##' @importFrom magrittr "%>%"
##' @importFrom magrittr "%<>%"
##' @export
summarize_areas_simple <- function(
  population = 3800,
  kcal_requirement = NULL,
  household_people = 5.00,
  consumed_plants = NULL,
  proportion = NULL,
  forest_type = "oak_mixed_forest",
  wood = setup_wood_consumption(population = population, forest_type, ...),
  pasture = setup_diet_meat(population = population), ...){

  households <- population / household_people

  if (is.null(kcal_requirement)) {
    kcal_req_human_year <- setup_population_simple(population = population)$KcalHumanYear
  } else {
    kcal_req_human_year <- setup_population_simple(population = population,
                                                   mode = "manual",
                                                   kcal_requirement = kcal_requirement)$KcalHumanYear
  }



  if (!is.null(consumed_plants)) {
    plants <- setup_diet_veg(population = population,
                             kcal_req_human_year = kcal_req_human_year,
                             consumed_plants = consumed_plants,
                             proportion = proportion)
  } else {
    plants <- setup_diet_veg(population = population, kcal_req_human_year = kcal_req_human_year)
  }

  total_ha <- dplyr::data_frame(
    Category = c("Settlement",
                 "Plants",
                 "Pasture",
                 "Wood"),
    Area_ha = c(area_village(population = population),
                plants$AreaPlants,
                pasture$AreaPasture,
                wood$area_wood_production_ha
                ),
    Area_prop = Area_ha/sum(Area_ha))


  ### plot
 return(total_ha)
}

